==> wallaroo-2023.2.1rc1.tar.gz: wallaroo-2023.2.1rc1/wallaroo/wallaroo_ml_ops_api_client/models/assays_create_json_body_baseline_type_2.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
  from ..models.assays_create_json_body_baseline_type_2_sliding import \
      AssaysCreateJsonBodyBaselineType2Sliding





T = TypeVar("T", bound="AssaysCreateJsonBodyBaselineType2")


@attr.s(auto_attribs=True)
class AssaysCreateJsonBodyBaselineType2:
    """ 
        Attributes:
            sliding (AssaysCreateJsonBodyBaselineType2Sliding):
     """

    sliding: 'AssaysCreateJsonBodyBaselineType2Sliding'
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)


    def to_dict(self) -> Dict[str, Any]:
        sliding = self.sliding.to_dict()


        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "Sliding": sliding,
        })

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.assays_create_json_body_baseline_type_2_sliding import \
            AssaysCreateJsonBodyBaselineType2Sliding
        d = src_dict.copy()
        sliding = AssaysCreateJsonBodyBaselineType2Sliding.from_dict(d.pop("Sliding"))




        assays_create_json_body_baseline_type_2 = cls(
            sliding=sliding,
        )

        assays_create_json_body_baseline_type_2.additional_properties = d
        return assays_create_json_body_baseline_type_2

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> wallaroo-2023.3.0b0.tar.gz: wallaroo-2023.3.0b0/wallaroo/wallaroo_ml_ops_api_client/models/assays_create_json_body_baseline_type_2.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
  from ..models.assays_create_json_body_baseline_type_2_fixed import \
      AssaysCreateJsonBodyBaselineType2Fixed





T = TypeVar("T", bound="AssaysCreateJsonBodyBaselineType2")


@attr.s(auto_attribs=True)
class AssaysCreateJsonBodyBaselineType2:
    """ 
        Attributes:
            fixed (AssaysCreateJsonBodyBaselineType2Fixed):
     """

    fixed: 'AssaysCreateJsonBodyBaselineType2Fixed'
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)


    def to_dict(self) -> Dict[str, Any]:
        fixed = self.fixed.to_dict()


        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "Fixed": fixed,
        })

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.assays_create_json_body_baseline_type_2_fixed import \
            AssaysCreateJsonBodyBaselineType2Fixed
        d = src_dict.copy()
        fixed = AssaysCreateJsonBodyBaselineType2Fixed.from_dict(d.pop("Fixed"))




        assays_create_json_body_baseline_type_2 = cls(
            fixed=fixed,
        )

        assays_create_json_body_baseline_type_2.additional_properties = d
        return assays_create_json_body_baseline_type_2

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
